import{s as a,c as s,a as e,C as t}from"./chunk-B4BG7PRW-Yti7nuyZ.js";import{_ as i}from"./mermaid.core-Db1smwpq.js";import"./chunk-FMBD7UC4--T31T-Ph.js";import"./chunk-55IACEB6-B5c1MW99.js";import"./chunk-QN33PNHL-BFiHplEr.js";import"./index-BNTnlj2R.js";var u={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{u as diagram};
